package Crypt::OpenSSL3::X509::Attribute;
$Crypt::OpenSSL3::X509::Attribute::VERSION = '0.008';
use strict;
use warnings;

1;

#ABSTRACT: An X509 attribute

__END__

=pod

=encoding UTF-8

=head1 NAME

Crypt::OpenSSL3::X509::Attribute - An X509 attribute

=head1 VERSION

version 0.008

=head1 METHODS

=head2 count

=head2 create

=head2 create_by_NID

=head2 create_by_OBJ

=head2 create_by_txt

=head2 get_data

=head2 get_object

=head2 set_data

=head2 set_object

=head1 AUTHOR

Leon Timmermans <fawaka@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2025 by Leon Timmermans.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
