package Crypt::OpenSSL3::Timestamp::Accuracy;
$Crypt::OpenSSL3::Timestamp::Accuracy::VERSION = '0.008';
use strict;
use warnings;

use Crypt::OpenSSL3;

1;

# ABSTRACT: A Timestamp Protocol accuracy

__END__

=pod

=encoding UTF-8

=head1 NAME

Crypt::OpenSSL3::Timestamp::Accuracy - A Timestamp Protocol accuracy

=head1 VERSION

version 0.008

=head1 METHODS

=head2 new

=head2 get_micros

=head2 get_millis

=head2 get_seconds

=head2 set_micros

=head2 set_millis

=head2 set_seconds

=head1 AUTHOR

Leon Timmermans <fawaka@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2025 by Leon Timmermans.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
