package Crypt::OpenSSL3::ASN1::Time;
$Crypt::OpenSSL3::ASN1::Time::VERSION = '0.008';
use strict;
use warnings;

use Crypt::OpenSSL3;

1;

# ABSTRACT: An ASN1 Time

__END__

=pod

=encoding UTF-8

=head1 NAME

Crypt::OpenSSL3::ASN1::Time - An ASN1 Time

=head1 VERSION

version 0.008

=head1 METHODS

=head2 adj

=head2 check

=head2 cmp_time

=head2 compare

=head2 diff

=head2 dup

=head2 new

=head2 normalize

=head2 print

=head2 print_ex

=head2 set

=head2 set_string

=head2 set_string_X509

=head2 to_generalizedtime

=head2 to_time_t

=head2 to_tm

=head1 AUTHOR

Leon Timmermans <fawaka@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2025 by Leon Timmermans.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
